@@ -956,20 +956,13 @@ def setup():
 def main():
     from pyblockworld import World
 
+    #
+    # BEISPIEL 1
+    #
+    
     # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
     def b_key_pressed(world:World):
-        print("B pressed.")
-        x,y,z = world.player_position()
-
-        # Neue Blöcke können mit setBlock gesetzt werden.
-        # Verfügbare Materialien stehen in World.MATERIALS und umfassen
-        # air, default:brick, default:stone, default:sand, default:grass
-        print("Block types", World.MATERIALS)
-        world.setBlock(x,y,z, "default:brick")
-
-        # Mehrere Blöcke auf einmal abseits des Spielers platzieren
-        x,y,z = x,y,z+3
-        world.setBlocks(x,y,z, x+3,y+3,z+3, "default:grass")
+        print("B pressed. Player at", world.play_position)
         
     # Erstellen einer neuen Welt
     world = World()
@@ -977,6 +970,27 @@ def main():
     world.build_key_pressed = b_key_pressed
     # Die Welt wird gestartet
     world.run()
+
+    #
+    # BEISPIEL 2
+    #
+
+    # Nun werden beim Drücken der Taste ein paar Blöcke platziert.
+    def b_key_pressed(world:World):
+        # Neue Blöcke können mit setBlock gesetzt werden.
+        # Verfügbare Materialien stehen in World.MATERIALS und umfassen
+        # air, default:brick, default:stone, default:sand, default:grass
+        print("Block types", World.MATERIALS)
+        x,y,z = world.player_position()
+        world.setBlock(x,y,z, "default:brick")
+
+        # Mehrere Blöcke auf einmal abseits des Spielers platzieren
+        x,y,z = x,y,z+3
+        world.setBlocks(x,y,z, x+3,y+3,z+3, "default:grass")
+        
+    world = World()
+    world.build_key_pressed = b_key_pressed
+    world.run()
     
 
 if __name__ == '__main__':
